Scripting Reference
-------------------

.. toctree::
   :maxdepth: 1

   scripting_references/ncbi_taxonomy
   scripting_references/ncbi_gene
   scripting_references/geo
   scripting_references/go
   scripting_references/geneset
   scripting_references/dicty_phenotypes
   scripting_references/kegg
   scripting_references/resolwe
   scripting_references/annotation
   scripting_references/marker_genes
   scripting_references/serverfiles